
%Matlab code to re-create Figure 2 of Drake et al., "Stoichiometry
%constrains microbial response to root exudation- insights from a model and
%a field experiment in a temperate forest"

%This matlab script calls the function 'Drake_model', which is also
%included in the supplementary material zip file.


CN_s = [10 20 30];
Pulse_C = 50;
CN_enz = [2 3 4];
CN_m = [3.5 7 14];
CN_pulse = [25 100 500];
temperature = 15;
K_r = 0.85;
K_ep = 0.0005;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%% Performs runs with varying CN_pulse;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

[BC10, EC10, Mn10, PAN10, Rtotal10] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(1),temperature);
[BC100, EC100, Mn100, PAN100, Rtotal100] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(2),temperature);
[BC1000, EC1000, Mn1000, PAN1000, Rtotal1000] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(3),temperature);

BC= [BC10 BC100 BC1000];
EC= [EC10 EC100 EC1000];
Mn= [Mn10 Mn100 Mn1000];
PAN= [PAN10 PAN100 PAN1000];
Rtotal= [Rtotal10 Rtotal100 Rtotal1000];


%Set figure size
scrsz = get(0,'ScreenSize');
h = figure('Position',[1 1 scrsz(3)*.8 scrsz(4)*.9]);

%sets default color scheme for figures;
whitebg('w') %create a figure with a white color scheme
%set(0,'DefaultAxesLineStyleOrder','-|--|:');
set(0,'DefaultAxesColorOrder',[1 0 0; 0 0 1; 0 0 0]);
% set(0,'DefaultAxesColorOrder',[0 0 0]);


subplot(4,4,1)
plot(Rtotal, 'LineWidth', 1.3);  ylabel({'Respiration' ; '(ug C g^-^1 hr^-^1)'},'fontsize', 18);
% axis([9900, +Inf, 0, 2]);
axis([9900, +Inf, 0.5, 2]);
legend('25', '50', '100','Location','NorthEast');
title('Exudate C:N','fontsize', 18);

subplot(4,4,5)
plot(BC, 'LineWidth', 1.3);  ylabel({'Microbial Biomass'; '(ug C g^-^1)'},'fontsize', 18);
% axis([9900, +Inf, -Inf, +Inf]);
axis([9900, +Inf, 23, 35]);

subplot(4,4,9)
plot(EC, 'LineWidth', 1.3);  ylabel({'Exoenzymes'; '(ug C g^-^1)'},'fontsize', 18);
% axis([9900, +Inf, -Inf, +Inf]);
axis([9900, +Inf, 0.45, 0.65]);

subplot(4,4,13)
plot(Mn, 'LineWidth', 1.3);  ylabel({'N mineralization' ; '(ug N g^-^1 hr^-^1)'},'fontsize', 18);
axis([9900, +Inf, -0.005, 0.055]);
% axis([9900, +Inf, 0, .05]);


% 
%  subplot(5,1,5)
%  plot(PAN, 'LineWidth', 1.5);  ylabel('PAN');
%  axis([9900, +Inf, -Inf, +Inf]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;












%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%% Performs runs with varying CN_s;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

[BC10, EC10, Mn10, DOC10, Rtotal10] = Drake_model(K_r,K_ep,CN_s(1),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(2),temperature);
[BC30, EC30, Mn30, DOC30, Rtotal30] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(2),temperature);
[BC50, EC50, Mn50, DOC50, Rtotal50] = Drake_model(K_r,K_ep,CN_s(3),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(2),temperature);

BC= [BC10 BC30 BC50];
EC= [EC10 EC30 EC50];
Mn= [Mn10 Mn30 Mn50];
DOC= [DOC10 DOC30 DOC50];
Rtotal= [Rtotal10 Rtotal30 Rtotal50];




subplot(4,4,2)
plot(Rtotal, 'LineWidth', 1.3); 
%axis([9900, +Inf, 0, 2]);
axis([9900, +Inf, 0.5, 2]);
legend('10', '20', '30','Location','NorthEast');
title('Soil C:N','fontsize', 18);

subplot(4,4,6)
plot(BC, 'LineWidth', 1.3);  
% axis([9900, +Inf, 0, 30]);
axis([9900, +Inf, 23, 35]);

subplot(4,4,10)
plot(EC, 'LineWidth', 1.3); 
axis([9900, +Inf, 0.45, 0.65]);
% axis([9900, +Inf, -Inf, +Inf]);

subplot(4,4,14)
plot(Mn, 'LineWidth', 1.3);  
% axis([9900, +Inf, 0, .05]);
axis([9900, +Inf, -0.005, 0.055]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;











%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%% Performs runs with varying CN_m;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

[BC3, EC3, Mn3, DOC3, Rtotal3] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(1),CN_pulse(2),temperature);
[BC5, EC5, Mn5, DOC5, Rtotal5] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(2),temperature);
[BC7, EC7, Mn7, DOC7, Rtotal7] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(3),CN_pulse(2),temperature);

BC= [BC3 BC5 BC7];
EC= [EC3 EC5 EC7];
Mn= [Mn3 Mn5 Mn7];
DOC= [DOC3 DOC5 DOC7];
Rtotal= [Rtotal3 Rtotal5 Rtotal7];





subplot(4,4,3)
plot(Rtotal, 'LineWidth', 1.3); 
% axis([9900, +Inf, 0, 2]);
axis([9900, +Inf, 0.5, 2]);
legend('3.5', '7', '14','Location','NorthEast');
title('Microbe C:N','fontsize', 18);

subplot(4,4,7)
plot(BC, 'LineWidth', 1.3);  
axis([9900, +Inf, 23, 35]);
% axis([9900, +Inf, -Inf, +Inf]);

subplot(4,4,11)
plot(EC, 'LineWidth', 1.3); 
axis([9900, +Inf, 0.45, 0.65]);
% axis([9900, +Inf, -Inf, +Inf]);

subplot(4,4,15)
plot(Mn, 'LineWidth', 1.3);  
% axis([9900, +Inf, 0, .05]);
axis([9900, +Inf, -0.005, 0.055]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;









%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%% Performs runs with varying CN_enz;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

[BC2, EC2, Mn2, DOC2, Rtotal2] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(1),CN_m(2),CN_pulse(2),temperature);
[BC3, EC3, Mn3, DOC3, Rtotal3] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(2),CN_m(2),CN_pulse(2),temperature);
[BC4, EC4, Mn4, DOC4, Rtotal4] = Drake_model(K_r,K_ep,CN_s(2),Pulse_C,CN_enz(3),CN_m(2),CN_pulse(2),temperature);

BC= [BC2 BC3 BC4];
EC= [EC2 EC3 EC4];
Mn= [Mn2 Mn3 Mn4];
DOC= [DOC2 DOC3 DOC4];
Rtotal= [Rtotal2 Rtotal3 Rtotal4];




subplot(4,4,4)
plot(Rtotal, 'LineWidth', 1.3); 
% axis([9900, +Inf, 0, 2]);
axis([9900, +Inf, 0.5, 2]);
legend('2', '3', '4','Location','NorthEast');
title('Exoenzyme C:N','fontsize', 18);

subplot(4,4,8)
plot(BC, 'LineWidth', 1.3);  
axis([9900, +Inf, 23, 35]);
% axis([9900, +Inf, -Inf, +Inf]);

subplot(4,4,12)
plot(EC, 'LineWidth', 1.3); 
axis([9900, +Inf, 0.45, 0.65]);
% axis([9900, +Inf, -Inf, +Inf]);

subplot(4,4,16)
plot(Mn, 'LineWidth', 1.3);  
% axis([9900, +Inf, 0, .05]);
axis([9900, +Inf, -0.005, 0.055]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

% gtext('Time step (hours)','FontSize',16);


%Save figure
% set(gcf,'PaperPositionMode','auto')
% print(h,'-dbmp','-r300',['C:\Documents and Settings\John\My Documents\Dropbox\Soil modeling\','Figure_16_color_largelabels.bmp']);